@@ -3,11 +3,13 @@ import io
 from PIL import Image
 import matplotlib
 
+
 def get_img_from_fig(fig, dpi=180):
     buf = io.BytesIO()
     from io import BytesIO
 
-    fig.savefig(buf, format="png", dpi=dpi,bbox_inches='tight',pad_inches=0,transparent=True)
+    fig.savefig(buf, format="png", dpi=dpi, bbox_inches='tight',
+                pad_inches=0, transparent=True)
     buf.seek(0)
     img_arr = np.frombuffer(buf.getvalue(), dtype=np.uint8)
     img = np.asarray(Image.open(BytesIO(img_arr)))
@@ -16,4 +18,3 @@ def get_img_from_fig(fig, dpi=180):
     #img = cv2.cvtColor(img, cv2.COLOR_BGRA2RGB)
 
     return img
-
